# Lineage

Genealogy management software

Stores lineage of family. Interactive command line interface to create and edit lineage of families. 


### Lineage
noun:
the series of families that somebody comes from originally  
वंश, वंशावली


# Install
###### Recommended (To install pipx click [here](https://github.com/pypa/pipx#install-pipx))
```
pipx install lineage-aq
```

###### or
```
pip install lineage-aq
```

#### Or upgrade by:
```
pipx upgrade lineage-aq
```
###### or
```
pip install --upgrade lineage-aq
```
# Usage

### Execute:
```
lineage
```


# Install from source
Poetry is required. For installation click [here](https://python-poetry.org/docs/#installation).

   Download the source and install the dependencies by running:
  
   ``` 
   git clone https://github.com/aqdasak/Lineage.git
   cd Lineage
   poetry install
   ```

### Run
In the source folder containing pyproject.toml, run
```
poetry shell
ytsort
```
